@@ -1,10 +1,23 @@
 #include "library/analysis/analysislibrarytablemodel.h"
 
+#include <QDateTime>
+
 #include "moc_analysislibrarytablemodel.cpp"
+#include "util/datetime.h"
 
 namespace {
 
-const QString RECENT_FILTER = "datetime_added > datetime('now', '-7 days')";
+inline QString recentFilter() {
+    // Create a user-formatted query equal to SQL query
+    // datetime_added > datetime('now', '-7 days')
+    QDateTime dt(QDateTime::currentDateTimeUtc());
+    dt = dt.addDays(-7);
+    const QString dateStr = QLocale::system().toString(dt.date(), QLocale::ShortFormat);
+
+    // FIXME alternatively, use "added:-days" and add the respective
+    // literal parser to DateAddedFilterNode
+    return QStringLiteral("added:>%1").arg(dateStr);
+}
 
 } // anonymous namespace
 
@@ -13,19 +26,22 @@ AnalysisLibraryTableModel::AnalysisLibraryTableModel(QObject* parent,
         : LibraryTableModel(parent, pTrackCollectionManager,
                             "mixxx.db.model.prepare") {
     // Default to showing recent tracks.
-    setSearch("", RECENT_FILTER);
+    setExtraFilter(recentFilter());
 }
 
 void AnalysisLibraryTableModel::showRecentSongs() {
     // Search with the recent filter.
-    search(currentSearch(), RECENT_FILTER);
+    setExtraFilter(recentFilter());
+    select();
 }
 
 void AnalysisLibraryTableModel::showAllSongs() {
     // Clear the recent filter.
-    search(currentSearch(), "");
+    setExtraFilter({});
+    select();
 }
 
 void AnalysisLibraryTableModel::searchCurrentTrackSet(const QString& text, bool useRecentFilter) {
-    search(text, useRecentFilter ? RECENT_FILTER : "");
+    setExtraFilter(useRecentFilter ? recentFilter() : QString{});
+    search(text);
 }
