@@ -304,7 +304,8 @@ void SoundDeviceNetwork::workerWriteProcess(NetworkOutputStreamWorkerPtr pWorker
         // kLogger.debug() << "workerWriteProcess: buffer full"
         //                 << "outChunkSize" << outChunkSize
         //                 << "readAvailable" << readAvailable
-        //                 << "writeExpected" << writeExpected << pWorker->getStreamTimeFrames();
+        //                 << "writeExpected" << writeExpected
+        //                 << "streamTime" << pWorker->getStreamTimeFrames();
         // catch up by skipping chunk
         m_pSoundManager->underflowHappened(25);
     }
@@ -313,9 +314,11 @@ void SoundDeviceNetwork::workerWriteProcess(NetworkOutputStreamWorkerPtr pWorker
     if (copyCount > 0) {
         if (writeExpected - copyCount > outChunkSize) {
             // Underflow
-            // kLogger.debug() << "workerWriteProcess: buffer empty";
+            // kLogger.debug() << "workerWriteProcess: buffer empty."
+            //                 << "Catch up with silence:" << writeExpected - copyCount
+            //                 << "streamTime" << pWorker->getStreamTimeFrames();;
             // catch up by filling buffer until we are synced
-            workerWriteSilence(pWorker, writeExpected - copyCount);
+            workerWriteSilence(pWorker, (writeExpected - copyCount) / m_numOutputChannels);
             m_pSoundManager->underflowHappened(24);
         } else if (writeExpected - copyCount > outChunkSize / 2) {
             // try to keep PAs buffer filled up to 0.5 chunks
@@ -331,7 +334,7 @@ void SoundDeviceNetwork::workerWriteProcess(NetworkOutputStreamWorkerPtr pWorker
         } else if (writeExpected < outChunkSize / 2) {
             // We will overshoot by more than a half of the new frames
             if (pWorker->outputDrift()) {
-                // kLogger.debug() << "SoundDeviceNetwork::workerWriteProcess() "
+                // kLogger.debug() << "workerWriteProcess() "
                 //                    "skip one frame"
                 //                 << (float)writeAvailable / outChunkSize
                 //                 << (float)readAvailable / outChunkSize;
@@ -497,7 +500,7 @@ void SoundDeviceNetwork::callbackProcessClkRef() {
     m_pSoundManager->readProcess(framesPerBuffer);
 
     {
-        ScopedTimer t(u"SoundDevicePortAudio::callbackProcess prepare %1",
+        ScopedTimer t(QStringLiteral("SoundDeviceNetwork::callbackProcess prepare %1"),
                 m_deviceId.name);
         m_pSoundManager->onDeviceOutputCallback(framesPerBuffer);
     }
