@@ -1,6 +1,13 @@
 #!/bin/bash
 # This script works with Debian, Ubuntu, and derivatives.
 # shellcheck disable=SC1091
+
+# Fail if not executed with bash
+if [ -z "$BASH_VERSION" ]; then
+    echo "Error: This script must be called as executable: ./debian_buildenv.sh setup" >&2
+    exit 1
+fi
+
 set -o pipefail
 
 case "$1" in
@@ -10,8 +17,8 @@ case "$1" in
         ;;
 
     setup)
-        source /etc/lsb-release 2>/dev/null
-        case "${DISTRIB_CODENAME}" in
+        source /etc/os-release 2>/dev/null
+        case "${VERSION_CODENAME}" in
             jammy|bullseye|victoria|vera|vanessa|virginia) # <= Ubuntu 22.04.5 LTS
                 PACKAGES_EXTRA=(
                     libqt6shadertools6-dev
@@ -23,8 +30,8 @@ case "$1" in
                 )
         esac
 
-        case "${DISTRIB_CODENAME}" in
-            jammy|oracular|bullseye|trixie|victoria|vera|vanessa|virginia|wilma|wildflower) # <= Ubuntu 24.10
+        case "${VERSION_CODENAME}" in
+            jammy|noble|oracular|bullseye|bookworm|victoria|vera|vanessa|virginia|wilma|wildflower) # <= Ubuntu 24.10
                 # qt6-svg-plugins not available
                 ;;
             *)
@@ -117,7 +124,6 @@ case "$1" in
             qml6-module-qtqml-workerscript \
             qml6-module-qtquick-controls \
             qml6-module-qtquick-layouts \
-            qml6-module-qtquick-nativestyle \
             qml6-module-qtquick-shapes \
             qml6-module-qtquick-templates \
             qml6-module-qtquick-window \
